@@ -10,20 +10,19 @@ subroutine gparc(icart,firstjcart)
 
    use sizes
    use compute_data
-   use pbc
+   use pbc, only : delta_vector, pbc_length
    implicit none
 
    ! SCALAR ARGUMENTS
-   integer :: icart,firstjcart
+   integer, intent(in) :: icart, firstjcart
 
    ! LOCAL SCALARS
    integer :: jcart
-   double precision :: datom, dtemp, xdiff, tol, &
-      short_tol, short_tol_scale
+   double precision :: datom, dtemp, xdiff, tol, short_tol, short_tol_scale
    double precision :: vdiff(3)
 
    jcart = firstjcart
-   do while ( jcart .ne. 0 )
+   do while ( jcart > 0 )
       !
       ! Cycle if this type is not to be computed
       !
